@@ -33,9 +33,10 @@
 #  define KJOBWIDGETS_DEPRECATED_NO_EXPORT KJOBWIDGETS_NO_EXPORT KJOBWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KJOBWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KJOBWIDGETS_NO_DEPRECATED
+#    define KJOBWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
